@@ -14,7 +14,7 @@ use Scalar::Util qw/openhandle/;
 use English qw/ -no_match_vars /;
 use AnyEvent;
 
-our $VERSION = version->new('0.4.2');
+our $VERSION = version->new('0.4.3');
 
 has name => (
     is            => 'rw',
@@ -272,24 +272,17 @@ Tail::Tool::File - Looks after individual files
 
 =head1 VERSION
 
-This documentation refers to Tail::Tool::File version 0.4.2.
+This documentation refers to Tail::Tool::File version 0.4.3.
 
 =head1 SYNOPSIS
 
-   use Tail::Tool::File;
-
-   # Brief but working code example(s) here showing the most common usage(s)
-   # This section will be as far as many users bother reading, so make it as
-   # educational and exemplary as possible.
+    use Tail::Tool::File;
 
+    # Create a new Tail::Tool::File object
+    my $file = Tail::Tool::File->new( '/my/file' );
 
 =head1 DESCRIPTION
 
-A full description of the module and its features.
-
-May include numerous subsections (i.e., =head2, =head3, etc.).
-
-
 =head1 SUBROUTINES/METHODS
 
 =head2 C<watch ()>
