@@ -11,7 +11,7 @@ use warnings;
 use version;
 use English qw/ -no_match_vars /;
 
-our $VERSION = version->new('0.4.2');
+our $VERSION = version->new('0.4.3');
 
 has post => (
     is       => 'ro',
@@ -36,16 +36,12 @@ Tail::Tool::PostProcess - The parent module for plugins that change individual l
 
 =head1 VERSION
 
-This documentation refers to Tail::Tool::PostProcess version 0.4.2.
+This documentation refers to Tail::Tool::PostProcess version 0.4.3.
 
 =head1 SYNOPSIS
 
-   use Tail::Tool::PostProcess;
-
-   # Brief but working code example(s) here showing the most common usage(s)
-   # This section will be as far as many users bother reading, so make it as
-   # educational and exemplary as possible.
-
+   # This module is for other to extend it doesn't do anything it self.
+   extends 'Tail::Tool::PostProcess';
 
 =head1 DESCRIPTION
 
