@@ -12,7 +12,7 @@ use version;
 use Carp;
 use English qw/ -no_match_vars /;
 
-our $VERSION = version->new('0.4.2');
+our $VERSION = version->new('0.4.3');
 
 has post => (
     is       => 'ro',
@@ -38,17 +38,13 @@ Tail::Tool::PreProcess - Parent module for Plugins that perform pre-processing t
 
 =head1 VERSION
 
-This documentation refers to Tail::Tool::PreProcess version 0.4.2.
+This documentation refers to Tail::Tool::PreProcess version 0.4.3.
 
 
 =head1 SYNOPSIS
 
-   use Tail::Tool::PreProcess;
-
-   # Brief but working code example(s) here showing the most common usage(s)
-   # This section will be as far as many users bother reading, so make it as
-   # educational and exemplary as possible.
-
+   # This module is for other to extend it doesn't do anything it self.
+   extends 'Tail::Tool::PreProcess';
 
 =head1 DESCRIPTION
 
